FPDF_CharsetFontMap_ class final
Struct: FPDF_CharsetFontMap Provides the name of a font to use for a given charset value.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - charset ↔ int
-
Character Set Enum value, see FXFONT_*_CHARSET above.
getter/setter pair
-
fontname
↔ Pointer<
Char> -
Name of default font to use with that charset.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited