FPDF_LIBRARY_CONFIG_ class final

Process-wide options for initializing the library.

Inheritance
Implemented types
Available extensions

Constructors

FPDF_LIBRARY_CONFIG_()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
m_FontLibraryType FPDF_FONT_BACKEND_TYPE
no setter
m_FontLibraryTypeAsInt int
Explicit specification of font library to use when |m_RendererType| is set to |FPDF_RENDERERTYPE_SKIA|. |m_FontLibraryType| must be a valid value for |FPDF_LIBRARY_CONFIG| versions of this level or higher, or else the initialization will fail with an immediate crash. Note that use of a specified |FPDF_FONT_BACKEND_TYPE| value for which the corresponding font library is not included in the build will similarly fail with an immediate crash.
getter/setter pair
m_pIsolate Pointer<Void>
Pointer to the v8::Isolate to use, or NULL to force PDFium to create one.
getter/setter pair
m_pPlatform Pointer<Void>
Pointer to the V8::Platform to use.
getter/setter pair
m_pUserFontPaths Pointer<Pointer<Char>>
Array of paths to scan in place of the defaults when using built-in FXGE font loading code. The array is terminated by a NULL pointer. The Array may be NULL itself to use the default paths. May be ignored entirely depending upon the platform.
getter/setter pair
m_RendererType FPDF_RENDERER_TYPE
no setter
m_RendererTypeAsInt int
Explicit specification of 2D graphics rendering library to use. |m_RendererType| must be a valid value for |FPDF_LIBRARY_CONFIG| versions of this level or higher, or else the initialization will fail with an immediate crash. Note that use of a specified |FPDF_RENDERER_TYPE| value for which the corresponding 2D graphics rendering library is not included in the build will similarly fail with an immediate crash.
getter/setter pair
m_v8EmbedderSlot int
The embedder data slot to use in the v8::Isolate to store PDFium's per-isolate data. The value needs to be in the range [0, |v8::Internals::kNumIsolateDataLots|). Note that 0 is fine for most embedders.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
Version number of the interface. Currently must be 2. Support for version 1 will be deprecated in the future.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited