FPDF_FILEHANDLER_ class final
Structure for file reading or writing (I/O).
Note: This is a handler and should be implemented by callers, and is only used from XFA.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
clientData
↔ Pointer<
Void> -
User-defined data.
Note: Callers can use this field to track controls.
getter/setter pair
-
Flush
↔ Pointer<
NativeFunction< FPDF_RESULT Function(Pointer< >Void> clientData)> -
Callback function to flush all internal accessing buffers.
getter/setter pair
-
GetSize
↔ Pointer<
NativeFunction< FPDF_DWORD Function(Pointer< >Void> clientData)> -
Callback function to retrieve the current file stream size.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ReadBlock
↔ Pointer<
NativeFunction< FPDF_RESULT Function(Pointer< >Void> clientData, FPDF_DWORD offset, Pointer<Void> buffer, FPDF_DWORD size)> -
Callback function to read data from the current file stream.
getter/setter pair
-
Release
↔ Pointer<
NativeFunction< Void Function(Pointer< >Void> clientData)> -
Callback function to release the current file stream object.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Truncate
↔ Pointer<
NativeFunction< FPDF_RESULT Function(Pointer< >Void> clientData, FPDF_DWORD size)> -
Callback function to change file size.
getter/setter pair
-
WriteBlock
↔ Pointer<
NativeFunction< FPDF_RESULT Function(Pointer< >Void> clientData, FPDF_DWORD offset, Pointer<Void> buffer, FPDF_DWORD size)> -
Callback function to write data into the current file stream.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited