FPDF_FILEWRITE_ class final
Structure for custom file write
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version ↔ int
-
Version number of the interface. Currently must be 1.
getter/setter pair
-
WriteBlock
↔ Pointer<
NativeFunction< Int Function(Pointer< >FPDF_FILEWRITE_> self, Pointer<Void> data, UnsignedLong size)> -
Method: WriteBlock
Output a block of data in your custom way.
Interface Version:
1
Implementation Required:
Yes
Comments:
Called by function FPDF_SaveDocument
Parameters:
self - Pointer to the structure itself
data - Pointer to a buffer to output
size - The size of the buffer.
Return value:
Should be non-zero if successful, zero for error.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited